rayoptics.elem package
======================

.. automodule:: rayoptics.elem
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   rayoptics.elem.elements
   rayoptics.elem.layout
   rayoptics.elem.parttree
   rayoptics.elem.profiles
   rayoptics.elem.surface
   rayoptics.elem.transform
